@@ -18,21 +18,21 @@ import cwltool.context
 def cli():
    pass
 
-# Start of the docker-compose using d2s-cwl-workflows yaml
-docker_compose_cmd = 'docker-compose -f d2s-cwl-workflows/docker-compose.yaml '
+# Start of the docker-compose using d2s-core yml
+docker_compose_cmd = 'docker-compose -f d2s-core/docker-compose.yml '
 
 # Used for autocompletion
 def get_services_list(ctx, args, incomplete):
-    # TODO: automate by parsing the docker-compose.yaml
+    # TODO: automate by parsing the docker-compose.yml
     return filter(lambda x: x.startswith(incomplete), [ 'demo',
-    'graphdb', 'virtuoso', 'tmp-virtuoso', 'blazegraph', 'allegrograph', 'anzograph', 'fuseki',
-    'into-the-graph', 'ldf-server', 'comunica', 'notebook',
+    'graphdb', 'graphdb-ee', 'virtuoso', 'tmp-virtuoso', 'blazegraph', 'allegrograph', 'anzograph', 'fuseki',
+    'notebook', 'spark-notebook', 'into-the-graph', 'ldf-server', 'comunica', 'biothings-studio', 'docket',
     'api', 'drill', 'postgres', 'proxy', 'filebrowser', 'rmlstreamer', 'rmltask',
-    'limes-server', 'neo4j' ])
+    'limes-server', 'mapeathor', 'neo4j', 'nanobench', 'fairdatapoint' ])
 def get_datasets_list(ctx, args, incomplete):
     return filter(lambda x: x.startswith(incomplete), os.listdir("./datasets"))
 def get_workflows_list(ctx, args, incomplete):
-    return filter(lambda x: x.startswith(incomplete), os.listdir("./d2s-cwl-workflows/workflows"))
+    return filter(lambda x: x.startswith(incomplete), os.listdir("./d2s-core/cwl/workflows"))
 def get_workflow_history(ctx, args, incomplete):
     # Sorted from latest to oldest
     files = list(filter(lambda x: x.startswith(incomplete), os.listdir("./workspace/logs")))
@@ -44,16 +44,7 @@ def get_running_workflows(ctx, args, incomplete):
     return filter(lambda x: datetime.datetime.fromtimestamp(os.path.getmtime("./workspace/logs/" + x)) > (datetime.datetime.now() - datetime.timedelta(minutes=2)), files)
 def get_running_processes(ctx, args, incomplete):
     # Show running processes to be stopped
-    return [os.system("ps ax | grep -v time | grep '[c]wl-runner' | awk '{print $1}'")]
-
-# Return the current dir where the command is run
-def getCurrentDir():
-    if os.name == 'nt':
-        # If Windows
-        return '$\{PWD\}'
-    else:
-        # Linux and MacOS
-        return '$(pwd)'
+    return [os.system("ps ax | grep '[c]wl-runner' | awk '{print $1}'")]
 
 # Change permissions to 777 recursively. 
 # See https://stackoverflow.com/questions/16249440/changing-file-permission-in-python
@@ -87,6 +78,7 @@ def init(ctx, projectname):
 
     config = configparser.ConfigParser()
     config['d2s'] = {}
+    config['d2s']['path'] = os.getcwd() + '/' + projectname
 
     click.echo(click.style('[d2s] ', bold=True) + 'You can generate a new project on GitHub using the provided template:')
     click.secho('https://github.com/MaastrichtU-IDS/d2s-transform-template/generate', bold=True)
@@ -98,8 +90,8 @@ def init(ctx, projectname):
     os.system('git clone --quiet --recursive ' + d2s_repository_url + ' ' + projectname)
     os.chdir(projectname)
     click.echo(click.style('[d2s]', bold=True) + ' Git repository cloned.')
-    if not os.path.exists('./d2s-cwl-workflows'):
-        os.system('git submodule add --recursive https://github.com/MaastrichtU-IDS/d2s-cwl-workflows.git')
+    if not os.path.exists('./d2s-core'):
+        os.system('git submodule add --recursive https://github.com/MaastrichtU-IDS/d2s-core.git')
 
     # Create workspace directories and chmod 777
     listToCreate = ["input", "output", "import", "output/tmp-outdir", "resources",
@@ -108,10 +100,6 @@ def init(ctx, projectname):
     for fileToCreate in listToCreate:
         os.makedirs('workspace/' + fileToCreate, exist_ok=True)
     chmod777('workspace')
-    # Copy load.sh in workspace for Virtuoso bulk load
-    shutil.copyfile('d2s-cwl-workflows/support/virtuoso/load.sh', 'workspace/virtuoso/load.sh')
-    shutil.copyfile('d2s-cwl-workflows/support/virtuoso/load.sh', 'workspace/tmp-virtuoso/load.sh')
-    # TODO: improve this to include it in Docker deployment
 
 
     # Get RMLStreamer from home dir to avoid download each time
@@ -124,7 +112,7 @@ def init(ctx, projectname):
     chmod777('workspace/resources/RMLStreamer.jar')
 
     click.echo()
-    # Copy GraphDB zip file to the right folder in d2s-cwl-workflows
+    # Copy GraphDB zip file to the right folder in d2s-core
     click.echo(click.style('[d2s]', bold=True) + ' The GraphDB triplestore needs to be downloaded for licensing reason.\n'
         + 'Go to ' 
         + click.style('https://ontotext.com/products/graphdb/', bold=True) 
@@ -133,9 +121,9 @@ def init(ctx, projectname):
     graphdb_path = click.prompt(click.style('[?]', bold=True) + ' Enter the path to the GraphDB distribution 9.1.1 zip file used to build the Docker image. Default', default=user_home_dir + '/graphdb-free-9.1.1-dist.zip')
     # Get GraphDB installation file
     if os.path.exists(graphdb_path):
-        shutil.copy(graphdb_path, 'd2s-cwl-workflows/support/graphdb')
+        shutil.copy(graphdb_path, 'd2s-core/support/graphdb')
     else:
-        click.echo(click.style('[d2s]', bold=True) + ' GraphDB installation file not found. Copy the zip file in d2s-cwl-workflows/support/graphdb after download.')
+        click.echo(click.style('[d2s]', bold=True) + ' GraphDB installation file not found. Copy the zip file in d2s-core/support/graphdb after download.')
 
     with open('.d2sconfig', 'w') as configfile:
         config.write(configfile)
@@ -155,25 +143,32 @@ def init(ctx, projectname):
 @cli.command()
 @click.argument('services', nargs=-1, autocompletion=get_services_list)
 @click.option(
-    '--permissions/--images', default=False, 
+    '--images/--no-images', default=False, 
     help='Update files permissions (Docker images by default)')
-def update(services, permissions):
-    """Update Docker images"""
+@click.option(
+    '--permissions/--no-permissions', default=False, 
+    help='Update files permissions (Docker images by default)')
+@click.option(
+    '--submodules/--no-submodule', default=False, 
+    help='Update the Git submodules (d2s-core)')
+def update(services, images, permissions, submodules):
+    """Update d2s (images, permissions, submodules)"""
+    if submodules:
+        print("Update submodules: d2s-core")
+        project_dir = os.getcwd()
+        os.chdir('d2s-core')
+        os.system('git checkout master')
+        os.system('git pull')
+        os.chdir(project_dir)
     if permissions:
         listToUpdate = ["input", "output", "import", "dumps", "tmp-virtuoso", "virtuoso"]
         click.echo(click.style('[d2s]', bold=True) + ' Password might be asked to updates following folder permissions in workspace: ' + ", ".join(listToUpdate))
         for fileToUpdate in listToUpdate:
             chmod777('workspace/' + fileToUpdate)
             os.makedirs('workspace/' + fileToUpdate, exist_ok=True)
-        # Copy load.sh in workspace for Virtuoso bulk load
-        shutil.copyfile('d2s-cwl-workflows/support/virtuoso/load.sh', 'workspace/virtuoso/load.sh')
-        shutil.copyfile('d2s-cwl-workflows/support/virtuoso/load.sh', 'workspace/tmp-virtuoso/load.sh')
-        chmod777('workspace/virtuoso/load.sh')
-        chmod777('workspace/tmp-virtuoso/load.sh')
-        # TODO: improve this to include it in Docker deployment
         click.echo(click.style('[d2s]', bold=True) + ' Most permissions issues can be fixed by changing the owner of the file while running as administrator')
         click.secho('sudo chown -R ' + os.getuid() + ':' + os.getgid() + ' workspace', bold=True)
-    else:
+    if images:
         # Update Docker images (pull and build graphdb)
         services_string = " ".join(services)
         os.system(docker_compose_cmd + 'pull ' + services_string)
@@ -216,8 +211,8 @@ def start(services, deploy):
     
     # Run docker-compose:
     if deploy:
-        os.system(docker_compose_cmd + '-f d2s-cwl-workflows/docker-compose.'
-        + deploy + '.yaml up -d --force-recreate ' + services_string)
+        os.system(docker_compose_cmd + '-f d2s-core/deployments/'
+        + deploy + '.yml up -d --force-recreate ' + services_string)
     else:
         os.system(docker_compose_cmd + 'up -d --force-recreate ' + services_string)
 
@@ -235,10 +230,10 @@ def start(services, deploy):
         #     localGraphdbUrl = 'http://localhost:7200/rest/repositories'
         #     headers = {'Content-Type': 'multipart/form-data'}
         #     request = urllib.request.Request(localGraphdbUrl, 
-        #         open('d2s-cwl-workflows/support/graphdb-repo-config.ttl', 'rb'),
+        #         open('d2s-core/support/graphdb-repo-config.ttl', 'rb'),
         #                             headers=headers)
         #     response = urllib.request.urlopen(request)
-        #     os.system('curl -X POST http://localhost:7200/rest/repositories -F "config=@d2s-cwl-workflows/support/graphdb-repo-config.ttl" -H "Content-Type: multipart/form-data"')
+        #     os.system('curl -X POST http://localhost:7200/rest/repositories -F "config=@d2s-core/support/graphdb-repo-config.ttl" -H "Content-Type: multipart/form-data"')
     click.echo()
     click.echo(click.style('[d2s]', bold=True) 
         + ' You can now download data to run a first workflow:')
@@ -271,7 +266,7 @@ def services():
 def process_running():
     """List running workflows processes"""
     os.system('echo "PID    CPU  Mem Start    Command"')
-    os.system('ps ax -o pid,%cpu,%mem,start,command | grep -v time | grep "[c]wl-runner"')
+    os.system('ps ax -o pid,%cpu,%mem,start,command | grep "[c]wl-runner"')
 
 @cli.command()
 @click.argument('process', autocompletion=get_running_processes)
@@ -303,7 +298,7 @@ def download(datasets):
     """Download a dataset to be processed"""
     start_time = datetime.datetime.now()
     for dataset in datasets:
-        os.system('docker run -it -v ' + getCurrentDir() + ':/srv \
+        os.system('docker run -it -v ' + os.getcwd() + ':/srv \
             umids/d2s-bash-exec:latest \
             /srv/datasets/' + dataset + '/download/download.sh workspace/input/' + dataset)
         click.echo(click.style('[d2s] ' + dataset, bold=True) + ' dataset downloaded at ' 
@@ -318,6 +313,9 @@ def download(datasets):
 
 @cli.command()
 @click.argument('dataset', autocompletion=get_datasets_list)
+@click.option(
+    '--yarrrml/--turtle-rml', default=False, 
+    help='Use yarrrml mappings')
 @click.option(
     '--mapper/--streamer', default=False, 
     help='Run RML Streamer or Mapper')
@@ -330,13 +328,28 @@ def download(datasets):
 @click.option(
     '-p', '--parallelism', default='8',
     help='Run in parallel, depends on Task Slots availables')
-def rml(dataset, detached, mapper, openshift, parallelism):
+def rml(dataset, detached, yarrrml, mapper, openshift, parallelism):
     """Run RML Streamer"""
     if (detached):
         detached_arg = '-d'
     else:
         detached_arg = '-it'
 
+    rml_file_extension = '.rml.ttl'
+
+    # Convert .yarrr.yml files to .yarrr.rml.ttl
+    if yarrrml:
+        rml_file_extension = '.yarrr.rml.ttl'
+        for file in os.listdir('./datasets/' + dataset + '/mapping'):
+            mapping_filename = os.fsdecode(file)
+            if mapping_filename.endswith(".yarrr.yml"): 
+                # Run rmlmapper docker image
+                output_filename = mapping_filename.replace('.yarrr.yml', rml_file_extension)
+                click.echo(click.style('[d2s]', bold=True) + ' Converting YARRRML file: ' + mapping_filename + ' to datasets/' + dataset + '/mapping/' + output_filename)
+                yarrrml_cmd = 'docker run -it --rm -v ' + os.getcwd() + '/datasets:/app/datasets umids/yarrrml-parser:latest -i /app/datasets/' + dataset + '/mapping/' + mapping_filename + ' -o /app/datasets/' + dataset + '/mapping/' + output_filename
+                # Run yarrrml parser
+                os.system(yarrrml_cmd)
+
     if openshift:
         # Ask if need to copy file on OpenShift cluster
         click.echo(click.style('[d2s]', bold=True) + ' Running RMLStreamer on OpenShift. Make sure your logged in and in the right project.')
@@ -351,7 +364,7 @@ def rml(dataset, detached, mapper, openshift, parallelism):
 
     for file in os.listdir('./datasets/' + dataset + '/mapping'):
      mapping_filename = os.fsdecode(file)
-     if mapping_filename.endswith(".rml.ttl"): 
+     if mapping_filename.endswith(rml_file_extension): 
         # print(os.path.join(directory, filename))
         mapping_filepath = 'datasets/' + dataset + '/mapping/' + mapping_filename
         click.echo(click.style('[d2s]', bold=True) + ' Execute mappings from ' 
@@ -368,17 +381,18 @@ def rml(dataset, detached, mapper, openshift, parallelism):
             if mapper:
                 # Run rmlmapper docker image
                 output_filename = 'rmlmapper-' + mapping_filename.replace('.', '_') + '-' + dataset + '.nt'
-                rml_cmd = 'docker run ' + detached_arg + ' -v ' + getCurrentDir() + '/workspace:/mnt/workspace -v ' + getCurrentDir() + '/datasets:/mnt/datasets umids/rmlmapper:4.7.0 -m /mnt/datasets/' + dataset + '/mapping/' + mapping_filename + ' -o /mnt/workspace/import/' + output_filename
+                rml_cmd = 'docker run ' + detached_arg + ' -v ' + os.getcwd() + '/workspace:/mnt/workspace -v ' + os.getcwd() + '/datasets:/mnt/datasets umids/rmlmapper:4.7.0 -m /mnt/datasets/' + dataset + '/mapping/' + mapping_filename + ' -o /mnt/workspace/import/' + output_filename
             else:
                 # Run RMLStreamer in running Apache Flink
                 output_filename = 'rmlstreamer-' + mapping_filename.replace('.', '_') + '-' + dataset + '.nt'
-                rml_cmd = 'docker exec ' + detached_arg + ' d2s-cwl-workflows_rmlstreamer_1 /opt/flink/bin/flink run -c io.rml.framework.Main /opt/RMLStreamer.jar --path /mnt/datasets/' + dataset + '/mapping/' + mapping_filename + ' --outputPath /mnt/workspace/import/' + output_filename + ' --job-name "[d2s] RMLStreamer ' + mapping_filename + ' - ' + dataset + '"'
+                rml_cmd = 'docker exec ' + detached_arg + ' d2s-rmlstreamer /opt/flink/bin/flink run -c io.rml.framework.Main /opt/RMLStreamer.jar --path /mnt/datasets/' + dataset + '/mapping/' + mapping_filename + ' --outputPath /mnt/workspace/import/' + output_filename + ' --job-name "[d2s] RMLStreamer ' + mapping_filename + ' - ' + dataset + '"'
                 click.echo(click.style('[d2s]', bold=True) + ' Check the jobs running at ' 
                     + click.style('http://localhost:8078/#/job/running', bold=True))
                 ## Try parallelism:
-                # rml_cmd = 'docker exec ' + detached_arg + ' d2s-cwl-workflows_rmlstreamer_1 /opt/flink/bin/flink run -p ' + parallelism + ' -c io.rml.framework.Main /mnt/workspace/resources/RMLStreamer.jar --path /mnt/datasets/' + dataset + '/mapping/' + mapping_filename + ' --outputPath /mnt/workspace/import/' + output_filename + ' --job-name "[d2s] RMLStreamer ' + mapping_filename + ' - ' + dataset + '" --parallelism ' + parallelism + ' --enable-local-parallel'
+                # rml_cmd = 'docker exec ' + detached_arg + ' d2s-rmlstreamer /opt/flink/bin/flink run -p ' + parallelism + ' -c io.rml.framework.Main /mnt/workspace/resources/RMLStreamer.jar --path /mnt/datasets/' + dataset + '/mapping/' + mapping_filename + ' --outputPath /mnt/workspace/import/' + output_filename + ' --job-name "[d2s] RMLStreamer ' + mapping_filename + ' - ' + dataset + '" --parallelism ' + parallelism + ' --enable-local-parallel'
         
         # Run RML processor
+        print(rml_cmd)
         os.system(rml_cmd)
         # TODO: store logs in a file and get the run time. Use subprocess.call
         # with open('workspace/logs/' + output_filename + '.log', 'a') as output:
@@ -390,7 +404,7 @@ def rml(dataset, detached, mapper, openshift, parallelism):
         click.secho('workspace/import/' + output_filename, bold=True)
     
     # Try parallelism:
-    # rmlstreamer_cmd = 'docker exec -d d2s-cwl-workflows_rmlstreamer_1 /opt/flink/bin/flink run -p 4 /mnt/workspace/resources/RMLStreamer.jar --path /mnt/datasets/' + dataset + '/mapping/rml-mappings.ttl --outputPath /mnt/workspace/import/rml-output-' + dataset + '.nt --job-name "[d2s] RMLStreamer ' + dataset + '" --enable-local-parallel'
+    # rmlstreamer_cmd = 'docker exec -d d2s-rmlstreamer /opt/flink/bin/flink run -p 4 /mnt/workspace/resources/RMLStreamer.jar --path /mnt/datasets/' + dataset + '/mapping/rml-mappings.ttl --outputPath /mnt/workspace/import/rml-output-' + dataset + '.nt --job-name "[d2s] RMLStreamer ' + dataset + '" --enable-local-parallel'
     # Try to use docker-compose, but exec dont resolve from the -f file
     # rmlstreamer_cmd = docker_compose_cmd + 'exec -d rmlstreamer /opt/flink/bin/flink run /mnt/workspace/resources/RMLStreamer.jar --path /mnt/datasets/' + dataset + '/mapping/rml-mappings.ttl --outputPath /mnt/workspace/import/rml-output-' + dataset + '.nt --job-name "[d2s] RMLStreamer ' + dataset + '"'
     # print(rmlstreamer_cmd)
@@ -409,7 +423,7 @@ def run(workflow, dataset, get_mappings, detached):
     start_time = datetime.datetime.now()
     config = configparser.ConfigParser()
     config.read('.d2sconfig')
-    cwl_workflow_path = 'd2s-cwl-workflows/workflows/' + workflow
+    cwl_workflow_path = 'd2s-core/cwl/workflows/' + workflow
     dataset_config_path = 'datasets/' + dataset + '/config.yml'
 
     # TODO: Trying to fix issue where virtuoso bulk load only the first dataset we run
@@ -429,11 +443,14 @@ def run(workflow, dataset, get_mappings, detached):
         os.remove(file)
 
     if (detached):
-        # TODO: Find a better solution to work on windows
-        cwl_command = 'nohup time '
+        # TODO: Find a better solution to work on windows.
+        # time allows to get running time of detached process but require to be installed
+        # e.g. yum install time
+        # cwl_command = 'nohup time '
+        cwl_command = 'nohup '
     else:
         cwl_command = ''
-    cwl_command = cwl_command +'cwl-runner --custom-net d2s-cwl-workflows_network --outdir {0}/output --tmp-outdir-prefix={0}/output/tmp-outdir/ --tmpdir-prefix={0}/output/tmp-outdir/tmp- {1} {2}'.format('workspace',cwl_workflow_path,dataset_config_path)
+    cwl_command = cwl_command +'cwl-runner --custom-net d2s-core_network --outdir {0}/output --tmp-outdir-prefix={0}/output/tmp-outdir/ --tmpdir-prefix={0}/output/tmp-outdir/tmp- {1} {2}'.format('workspace',cwl_workflow_path,dataset_config_path)
     if (detached):
         log_filename = workflow + '-' + dataset + '-' + datetime.datetime.now().strftime("%Y%m%d-%H%M%S") + '.txt'
         cwl_command = cwl_command + ' > workspace/logs/' + log_filename + ' &'
@@ -475,14 +492,14 @@ def run(workflow, dataset, get_mappings, detached):
     # dataset_config_file = open('datasets/' + dataset + '/config.yml', 'r')
     # # Define cwl-runner workspace
     # runtime_context = cwltool.context.RuntimeContext()
-    # runtime_context.custom_net = 'd2s-cwl-workflows_network'
+    # runtime_context.custom_net = 'd2s-core_network'
     # runtime_context.outdir = 'workspace/output'
     # runtime_context.tmp_outdir_prefix = 'workspace/output/tmp-outdir/'
     # runtime_context.tmpdir_prefix = 'workspace/output/tmp-outdir/tmp-'
     # cwl_factory = cwltool.factory.Factory(runtime_context=runtime_context)
     # # Run CWL workflow
     # run_workflow = cwl_factory.make(cwl_workflow_path) # the .cwl file
-    # result = run_workflow(inp=dataset_config_file.read())  # the config yaml
+    # result = run_workflow(inp=dataset_config_file.read())  # the config yml
     # print('Running!')
     # print(result)
 
@@ -497,35 +514,71 @@ def dataset():
     """Create a new dataset from template in datasets folder"""
     # Automatically fill data about the workflow (git repo URL of mappings)
     # TODO: make it an array of obj
-    dataset_id = click.prompt(click.style('[?]', bold=True) 
-        + ' Enter the identifier of your datasets, e.g. wikipathways (lowercase, no space or weird characters)')
-    dataset_name = click.prompt(click.style('[?]', bold=True) 
-        + ' Enter a human-readable name for your datasets, e.g. WikiPathways')
-    dataset_description = click.prompt(click.style('[?]', bold=True) 
-        + ' Enter a description for this dataset')
-    publisher_name = click.prompt(click.style('[?]', bold=True) 
-        + ' Enter complete name for the institutions publishing the data and its affiliation, e.g. Institute of Data Science at Maastricht University')
-    publisher_url = click.prompt(click.style('[?]', bold=True) 
-        + ' Enter a valid URL for the publisher homepage. Default', 
-        default='https://maastrichtuniversity.nl/ids')
-    source_license = click.prompt(click.style('[?]', bold=True) 
-        + ' Enter a valid URL to the license informations about the original dataset. Default', 
-        default='http://creativecommons.org/licenses/by-nc/4.0/legalcode')
-    rdf_license = click.prompt(click.style('[?]', bold=True) 
-        + ' Enter a valid URL to the license informations about the RDF distribution of the dataset. Default', 
-        default='http://creativecommons.org/licenses/by-nc/4.0/legalcode')
-
-    dataset_folder_path = 'datasets/' + dataset_id
-    shutil.copytree('d2s-cwl-workflows/support/template/dataset', dataset_folder_path)
+    metadataArray = []
+    metadataArray.append({'id': 'dataset_id', 'description': 'Enter the identifier of your datasets, e.g. drugbank (lowercase, no space or weird characters)'})
+    metadataArray.append({'id': 'dataset_name', 'description': 'Enter a human-readable name for your datasets, e.g. DrugBank'})
+    metadataArray.append({'id': 'dataset_description', 'description': 'Enter a description for this dataset'})
+    metadataArray.append({'id': 'publisher_name', 'default': 'Institute of Data Science at Maastricht University', 'description': 'Enter complete name for the institutions publishing the data and its affiliation, e.g. Institute of Data Science at Maastricht University'})
+    metadataArray.append({'id': 'publisher_url', 'default': 'https://maastrichtuniversity.nl/ids', 'description': 'Enter a valid URL for the publisher homepage. Default'})
+    metadataArray.append({'id': 'source_license', 'default': 'http://creativecommons.org/licenses/by-nc/4.0/legalcode', 'description': 'Enter a valid URL to the license informations about the original dataset'})
+    metadataArray.append({'id': 'inputFormat', 'default': 'application/xml', 'description': 'Enter the format of the source file to transform'})
+    metadataArray.append({'id': 'homepage', 'default': 'http://d2s.semanticscience.org/', 'description': 'Enter the URL of the dataset homepage'})
+    metadataArray.append({'id': 'accessURL', 'default': 'https://www.drugbank.ca/releases/latest', 'description': 'Specify URL of the directory containing the file(s) of interest (not the direct file URL)'})
+    metadataArray.append({'id': 'references', 'default': 'https://www.ncbi.nlm.nih.gov/pubmed/29126136', 'description': 'Enter the URL of a publication supporting the dataset'})
+    metadataArray.append({'id': 'keyword', 'default': 'drug', 'description': 'Enter a keyword to describe the dataset'})
+    metadataArray.append({'id': 'theme', 'default': 'http://ncicb.nci.nih.gov/xml/owl/EVS/Thesaurus.owl#C54708', 'description': 'Enter the URL to an ontology concept describing the dataset theme'})
+    metadataArray.append({'id': 'sparqlEndpoint', 'default': 'https://graphdb.dumontierlab.com/repositories/trek', 'description': 'Enter the URL of the final SPARQL endpoint to access the integrated dataset'})
+    metadataArray.append({'id': 'downloadURL', 'default': 'https://www.drugbank.ca/releases/5-1-1/downloads/all-full-database', 'description': 'Enter the URL to download the source file to be transformed'})
+    metadataArray.append({'id': 'rdfPublisherName', 'default': 'Institute of Data Science at Maastricht University', 'description': 'Enter the name for the publisher of the RDF distribution'})
+    metadataArray.append({'id': 'rdfPublisherPage', 'default': 'https://maastrichtuniversity.nl/ids', 'description': 'Enter a valid homepage URL for the publisher of the RDF distribution'})
+    metadataArray.append({'id': 'rdf_license', 'default': 'http://creativecommons.org/licenses/by-nc/4.0/legalcode', 'description': 'Enter a valid URL to the license informations about the RDF distribution of the dataset'})
+    metadataArray.append({'id': 'rdfDownloadURL', 'default': 'http://download.137.120.31.102.nip.io/#/', 'description': 'Enter a valid URL to download the RDF distribution'})
     
+    for metadataObject in metadataArray:
+        if 'default' in metadataObject:
+            metadataObject['value'] = click.prompt(click.style('[?]', bold=True) 
+            + ' ' + metadataObject['description'] + '. Default',
+            default=metadataObject['default'])
+        else:
+            metadataObject['value'] = click.prompt(click.style('[?]', bold=True) 
+            + ' ' + metadataObject['description'])
+
+    # dataset_id = click.prompt(click.style('[?]', bold=True) 
+    #     + ' Enter the identifier of your datasets, e.g. wikipathways (lowercase, no space or weird characters)')
+    # dataset_name = click.prompt(click.style('[?]', bold=True) 
+    #     + ' Enter a human-readable name for your datasets, e.g. WikiPathways')
+    # dataset_description = click.prompt(click.style('[?]', bold=True) 
+    #     + ' Enter a description for this dataset')
+    # publisher_name = click.prompt(click.style('[?]', bold=True) 
+    #     + ' Enter complete name for the institutions publishing the data and its affiliation, e.g. Institute of Data Science at Maastricht University')
+    # publisher_url = click.prompt(click.style('[?]', bold=True) 
+    #     + ' Enter a valid URL for the publisher homepage. Default', 
+    #     default='https://maastrichtuniversity.nl/ids')
+    # source_license = click.prompt(click.style('[?]', bold=True) 
+    #     + ' Enter a valid URL to the license informations about the original dataset. Default', 
+    #     default='http://creativecommons.org/licenses/by-nc/4.0/legalcode')
+    # rdf_license = click.prompt(click.style('[?]', bold=True) 
+    #     + ' Enter a valid URL to the license informations about the RDF distribution of the dataset. Default', 
+    #     default='http://creativecommons.org/licenses/by-nc/4.0/legalcode')
+
+
+    # rdf_license = click.prompt(click.style('[?]', bold=True) 
+    #     + ' Enter. Default', 
+    #     default='changeme')
+
+    dataset_id = metadataArray[0]['value']
+    dataset_folder_path = 'datasets/' + dataset_id
+    shutil.copytree('d2s-core/support/template/dataset', dataset_folder_path)
+    os.rename(dataset_folder_path + '/process-dataset.ipynb', dataset_folder_path + '/process-' + dataset_id + '.ipynb')
+    
+    # Replace metadata in metadata files
     for dname, dirs, files in os.walk(dataset_folder_path):
         for fname in files:
             fpath = os.path.join(dname, fname)
             with open(fpath) as f:
                 file_content = f.read()
-            file_content = file_content.replace("$dataset_id", dataset_id).replace("$dataset_name", dataset_name).replace("$dataset_description", dataset_description)
-            file_content = file_content.replace("$publisher_name", publisher_name).replace("$publisher_url", publisher_url)
-            file_content = file_content.replace("$source_license", source_license).replace("$rdf_license", rdf_license)
+            for metadataObject in metadataArray:
+                file_content = file_content.replace("$" + metadataObject['id'], metadataObject['value'])
             with open(fpath, "w") as f:
                 f.write(file_content)
     click.echo()
